@@ -17,12 +17,7 @@ from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_resource_groups.paginator import (
-    ListGroupResourcesPaginator,
-    ListGroupsPaginator,
-    SearchResourcesPaginator,
-)
-
+from .paginator import ListGroupResourcesPaginator, ListGroupsPaginator, SearchResourcesPaginator
 from .type_defs import (
     CreateGroupOutputTypeDef,
     DeleteGroupOutputTypeDef,
@@ -75,7 +70,7 @@ class Exceptions:
 
 class ResourceGroupsClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/resource-groups.html#ResourceGroups.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/resource-groups.html#ResourceGroups.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -84,8 +79,8 @@ class ResourceGroupsClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/resource-groups.html#ResourceGroups.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/resource-groups.html#ResourceGroups.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def create_group(
@@ -97,14 +92,14 @@ class ResourceGroupsClient:
         Configuration: List["GroupConfigurationItemTypeDef"] = None,
     ) -> CreateGroupOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/resource-groups.html#ResourceGroups.Client.create_group)
-        [Show boto3-stubs documentation](./client.md#create-group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/resource-groups.html#ResourceGroups.Client.create_group)
+        [Show boto3-stubs documentation](./client.md#create_group)
         """
 
     def delete_group(self, GroupName: str = None, Group: str = None) -> DeleteGroupOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/resource-groups.html#ResourceGroups.Client.delete_group)
-        [Show boto3-stubs documentation](./client.md#delete-group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/resource-groups.html#ResourceGroups.Client.delete_group)
+        [Show boto3-stubs documentation](./client.md#delete_group)
         """
 
     def generate_presigned_url(
@@ -115,40 +110,40 @@ class ResourceGroupsClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/resource-groups.html#ResourceGroups.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/resource-groups.html#ResourceGroups.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_group(self, GroupName: str = None, Group: str = None) -> GetGroupOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/resource-groups.html#ResourceGroups.Client.get_group)
-        [Show boto3-stubs documentation](./client.md#get-group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/resource-groups.html#ResourceGroups.Client.get_group)
+        [Show boto3-stubs documentation](./client.md#get_group)
         """
 
     def get_group_configuration(self, Group: str = None) -> GetGroupConfigurationOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/resource-groups.html#ResourceGroups.Client.get_group_configuration)
-        [Show boto3-stubs documentation](./client.md#get-group-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/resource-groups.html#ResourceGroups.Client.get_group_configuration)
+        [Show boto3-stubs documentation](./client.md#get_group_configuration)
         """
 
     def get_group_query(
         self, GroupName: str = None, Group: str = None
     ) -> GetGroupQueryOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/resource-groups.html#ResourceGroups.Client.get_group_query)
-        [Show boto3-stubs documentation](./client.md#get-group-query)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/resource-groups.html#ResourceGroups.Client.get_group_query)
+        [Show boto3-stubs documentation](./client.md#get_group_query)
         """
 
     def get_tags(self, Arn: str) -> GetTagsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/resource-groups.html#ResourceGroups.Client.get_tags)
-        [Show boto3-stubs documentation](./client.md#get-tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/resource-groups.html#ResourceGroups.Client.get_tags)
+        [Show boto3-stubs documentation](./client.md#get_tags)
         """
 
     def group_resources(self, Group: str, ResourceArns: List[str]) -> GroupResourcesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/resource-groups.html#ResourceGroups.Client.group_resources)
-        [Show boto3-stubs documentation](./client.md#group-resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/resource-groups.html#ResourceGroups.Client.group_resources)
+        [Show boto3-stubs documentation](./client.md#group_resources)
         """
 
     def list_group_resources(
@@ -160,8 +155,8 @@ class ResourceGroupsClient:
         NextToken: str = None,
     ) -> ListGroupResourcesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/resource-groups.html#ResourceGroups.Client.list_group_resources)
-        [Show boto3-stubs documentation](./client.md#list-group-resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/resource-groups.html#ResourceGroups.Client.list_group_resources)
+        [Show boto3-stubs documentation](./client.md#list_group_resources)
         """
 
     def list_groups(
@@ -171,29 +166,29 @@ class ResourceGroupsClient:
         NextToken: str = None,
     ) -> ListGroupsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/resource-groups.html#ResourceGroups.Client.list_groups)
-        [Show boto3-stubs documentation](./client.md#list-groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/resource-groups.html#ResourceGroups.Client.list_groups)
+        [Show boto3-stubs documentation](./client.md#list_groups)
         """
 
     def put_group_configuration(
         self, Group: str = None, Configuration: List["GroupConfigurationItemTypeDef"] = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/resource-groups.html#ResourceGroups.Client.put_group_configuration)
-        [Show boto3-stubs documentation](./client.md#put-group-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/resource-groups.html#ResourceGroups.Client.put_group_configuration)
+        [Show boto3-stubs documentation](./client.md#put_group_configuration)
         """
 
     def search_resources(
         self, ResourceQuery: "ResourceQueryTypeDef", MaxResults: int = None, NextToken: str = None
     ) -> SearchResourcesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/resource-groups.html#ResourceGroups.Client.search_resources)
-        [Show boto3-stubs documentation](./client.md#search-resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/resource-groups.html#ResourceGroups.Client.search_resources)
+        [Show boto3-stubs documentation](./client.md#search_resources)
         """
 
     def tag(self, Arn: str, Tags: Dict[str, str]) -> TagOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/resource-groups.html#ResourceGroups.Client.tag)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/resource-groups.html#ResourceGroups.Client.tag)
         [Show boto3-stubs documentation](./client.md#tag)
         """
 
@@ -201,13 +196,13 @@ class ResourceGroupsClient:
         self, Group: str, ResourceArns: List[str]
     ) -> UngroupResourcesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/resource-groups.html#ResourceGroups.Client.ungroup_resources)
-        [Show boto3-stubs documentation](./client.md#ungroup-resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/resource-groups.html#ResourceGroups.Client.ungroup_resources)
+        [Show boto3-stubs documentation](./client.md#ungroup_resources)
         """
 
     def untag(self, Arn: str, Keys: List[str]) -> UntagOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/resource-groups.html#ResourceGroups.Client.untag)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/resource-groups.html#ResourceGroups.Client.untag)
         [Show boto3-stubs documentation](./client.md#untag)
         """
 
@@ -215,16 +210,16 @@ class ResourceGroupsClient:
         self, GroupName: str = None, Group: str = None, Description: str = None
     ) -> UpdateGroupOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/resource-groups.html#ResourceGroups.Client.update_group)
-        [Show boto3-stubs documentation](./client.md#update-group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/resource-groups.html#ResourceGroups.Client.update_group)
+        [Show boto3-stubs documentation](./client.md#update_group)
         """
 
     def update_group_query(
         self, ResourceQuery: "ResourceQueryTypeDef", GroupName: str = None, Group: str = None
     ) -> UpdateGroupQueryOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/resource-groups.html#ResourceGroups.Client.update_group_query)
-        [Show boto3-stubs documentation](./client.md#update-group-query)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/resource-groups.html#ResourceGroups.Client.update_group_query)
+        [Show boto3-stubs documentation](./client.md#update_group_query)
         """
 
     @overload
@@ -232,13 +227,13 @@ class ResourceGroupsClient:
         self, operation_name: Literal["list_group_resources"]
     ) -> ListGroupResourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroupResources)[Show boto3-stubs documentation](./paginators.md#listgroupresourcespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroupResources)[Show boto3-stubs documentation](./paginators.md#listgroupresourcespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_groups"]) -> ListGroupsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroups)[Show boto3-stubs documentation](./paginators.md#listgroupspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroups)[Show boto3-stubs documentation](./paginators.md#listgroupspaginator)
         """
 
     @overload
@@ -246,5 +241,5 @@ class ResourceGroupsClient:
         self, operation_name: Literal["search_resources"]
     ) -> SearchResourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/resource-groups.html#ResourceGroups.Paginator.SearchResources)[Show boto3-stubs documentation](./paginators.md#searchresourcespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/resource-groups.html#ResourceGroups.Paginator.SearchResources)[Show boto3-stubs documentation](./paginators.md#searchresourcespaginator)
         """
